@@ -180,6 +180,12 @@ def parse(config_path):
                     'required': False,
                     'type': 'int'
                 },
+                {
+                    'key': 'throttled_reads_upper_threshold',
+                    'option': 'throttled-reads-upper-threshold',
+                    'required': False,
+                    'type': 'int'
+                },
                 {
                     'key': 'increase_reads_with',
                     'option': 'increase-reads-with',
@@ -216,6 +222,12 @@ def parse(config_path):
                     'required': False,
                     'type': 'int'
                 },
+                {
+                    'key': 'throttled_writes_upper_threshold',
+                    'option': 'throttled-writes-upper-threshold',
+                    'required': False,
+                    'type': 'int'
+                },
                 {
                     'key': 'increase_writes_with',
                     'option': 'increase-writes-with',
@@ -330,6 +342,12 @@ def parse(config_path):
                         'required': False,
                         'type': 'int'
                     },
+                    {
+                        'key': 'throttled_reads_upper_threshold',
+                        'option': 'throttled-reads-upper-threshold',
+                        'required': False,
+                        'type': 'int'
+                    },
                     {
                         'key': 'increase_reads_with',
                         'option': 'increase-reads-with',
@@ -366,6 +384,12 @@ def parse(config_path):
                         'required': False,
                         'type': 'int'
                     },
+                    {
+                        'key': 'throttled_writes_upper_threshold',
+                        'option': 'throttled-writes-upper-threshold',
+                        'required': False,
+                        'type': 'int'
+                    },
                     {
                         'key': 'increase_writes_with',
                         'option': 'increase-writes-with',
