@@ -84,6 +84,9 @@ def __ensure_provisioning_reads(table_name, table_key, gsi_name, gsi_key):
     consumed_read_units_percent = gsi_stats.get_consumed_read_units_percent(
         table_name, gsi_name)
 
+    throttled_read_count = gsi_stats.get_throttled_read_event_count(
+        table_name, gsi_name)
+
     if (consumed_read_units_percent == 0 and not
             get_gsi_option(
                 table_key,
@@ -120,6 +123,31 @@ def __ensure_provisioning_reads(table_name, table_key, gsi_name, gsi_key):
             update_needed = True
             updated_read_units = updated_provisioning
 
+    elif (throttled_read_count >= get_gsi_option(
+            table_key, gsi_key, 'throttled_reads_upper_threshold')):
+
+        if (get_gsi_option(table_key, gsi_key, 'increase_reads_unit') ==
+                'percent'):
+            updated_provisioning = calculators.increase_reads_in_percent(
+                updated_read_units,
+                get_gsi_option(table_key, gsi_key, 'increase_reads_with'),
+                table_name,
+                table_key,
+                gsi_name,
+                gsi_key,)
+        else:
+            updated_provisioning = calculators.increase_reads_in_units(
+                updated_read_units,
+                get_gsi_option(table_key, gsi_key, 'increase_reads_with'),
+                table_name,
+                table_key,
+                gsi_name,
+                gsi_key)
+
+        if updated_read_units != updated_provisioning:
+            update_needed = True
+            updated_read_units = updated_provisioning
+
     elif (consumed_read_units_percent <=
             get_gsi_option(table_key, gsi_key, 'reads_lower_threshold')):
 
@@ -178,6 +206,9 @@ def __ensure_provisioning_writes(table_name, table_key, gsi_name, gsi_key):
     consumed_write_units_percent = \
         gsi_stats.get_consumed_write_units_percent(table_name, gsi_name)
 
+    throttled_write_count = gsi_stats.get_throttled_write_event_count(
+        table_name, gsi_name)
+
     # Check if we should update write provisioning
     if (consumed_write_units_percent == 0 and not get_gsi_option(
             table_key, gsi_key, 'allow_scaling_down_writes_on_0_percent')):
@@ -212,6 +243,31 @@ def __ensure_provisioning_writes(table_name, table_key, gsi_name, gsi_key):
             update_needed = True
             updated_write_units = updated_provisioning
 
+    elif (throttled_write_count >= get_gsi_option(
+            table_key, gsi_key, 'throttled_writes_upper_threshold')):
+
+        if (get_gsi_option(table_key, gsi_key, 'increase_writes_unit') ==
+                'percent'):
+            updated_provisioning = calculators.increase_writes_in_percent(
+                updated_write_units,
+                get_gsi_option(table_key, gsi_key, 'increase_writes_with'),
+                table_name,
+                table_key,
+                gsi_name,
+                gsi_key)
+        else:
+            updated_provisioning = calculators.increase_writes_in_units(
+                updated_write_units,
+                get_gsi_option(table_key, gsi_key, 'increase_writes_with'),
+                table_name,
+                table_key,
+                gsi_name,
+                gsi_key)
+
+        if updated_write_units != updated_provisioning:
+            update_needed = True
+            updated_write_units = updated_provisioning
+
     elif (consumed_write_units_percent <=
             get_gsi_option(table_key, gsi_key, 'writes_lower_threshold')):
 
