@@ -56,6 +56,9 @@ def __ensure_provisioning_reads(table_name, key_name):
     consumed_read_units_percent = table_stats.get_consumed_read_units_percent(
         table_name)
 
+    throttled_read_count = table_stats.get_throttled_read_event_count(
+        table_name)
+
     if (consumed_read_units_percent == 0 and not
             get_table_option(
                 key_name, 'allow_scaling_down_reads_on_0_percent')):
@@ -84,6 +87,26 @@ def __ensure_provisioning_reads(table_name, key_name):
             update_needed = True
             updated_read_units = updated_provisioning
 
+    elif (throttled_read_count >=
+            get_table_option(key_name, 'throttled_reads_upper_threshold')):
+
+        if get_table_option(key_name, 'increase_reads_unit') == 'percent':
+            updated_provisioning = calculators.increase_reads_in_percent(
+                updated_read_units,
+                get_table_option(key_name, 'increase_reads_with'),
+                key_name,
+                table_name)
+        else:
+            updated_provisioning = calculators.increase_reads_in_units(
+                updated_read_units,
+                get_table_option(key_name, 'increase_reads_with'),
+                key_name,
+                table_name)
+
+        if updated_read_units != updated_provisioning:
+            update_needed = True
+            updated_read_units = updated_provisioning
+
     elif (consumed_read_units_percent <=
             get_table_option(key_name, 'reads_lower_threshold')):
 
@@ -133,6 +156,9 @@ def __ensure_provisioning_writes(table_name, key_name):
     consumed_write_units_percent = \
         table_stats.get_consumed_write_units_percent(table_name)
 
+    throttled_write_count = \
+        table_stats.get_throttled_write_event_count(table_name)
+
     # Check if we should update write provisioning
     if (consumed_write_units_percent == 0 and not
             get_table_option(
@@ -162,6 +188,26 @@ def __ensure_provisioning_writes(table_name, key_name):
             update_needed = True
             updated_write_units = updated_provisioning
 
+    elif (throttled_write_count >=
+            get_table_option(key_name, 'throttled_writes_upper_threshold')):
+
+        if get_table_option(key_name, 'increase_writes_unit') == 'percent':
+            updated_provisioning = calculators.increase_writes_in_percent(
+                updated_write_units,
+                get_table_option(key_name, 'increase_writes_with'),
+                key_name,
+                table_name)
+        else:
+            updated_provisioning = calculators.increase_writes_in_units(
+                updated_write_units,
+                get_table_option(key_name, 'increase_writes_with'),
+                key_name,
+                table_name)
+
+        if updated_write_units != updated_provisioning:
+            update_needed = True
+            updated_write_units = updated_provisioning
+
     elif (consumed_write_units_percent <=
             get_table_option(key_name, 'writes_lower_threshold')):
 
